==> npm-package-store-1.0.2.tgz: package/README.md <==
# NPM Package Store

A web app that displays updates for your globally installed NPM modules. Inspired by [Go Package Store](https://github.com/shurcooL/Go-Package-Store).

![Screenshot](http://i.imgur.com/MIvjI7t.png)

## Installation

    >git clone https://github.com/travishorn/npm-package-store.git
    >cd npm-package-store
    >npm install
    >npm start

Then just go to http://127.0.0.1:3000

You can modify the port NPM Package Store runs on with the PORT environment variable.

## To do

- Make into a binary that can be installed and executed globally
- Show change log if updates are available
- Search through installed modules
- Search and install modules from NPM registry
- Uninstall currently installed modules

## License

The MIT License (MIT)
Copyright © 2014 Travis Horn

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> npm-package-store-1.0.4.tgz: package/README.md <==
# npm Package Store

A web app that displays updates for your globally installed npm modules. Inspired by [Go Package Store](https://github.com/shurcooL/Go-Package-Store).

![Screenshot](http://i.imgur.com/MIvjI7t.png)

## Installation

    >npm install -g npm-package-store
    >npmstore

or

    >git clone https://github.com/travishorn/npm-package-store.git
    >cd npm-package-store
    >npm install
    >npm start

Then just go to http://127.0.0.1:3000

You can modify the port npm Package Store runs on with the PORT environment variable.

## To do

- Show change log if updates are available
- Search through installed modules
- Search and install modules from npm registry
- Uninstall currently installed modules

## License

The MIT License (MIT)
Copyright © 2015 Travis Horn

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
